@@ -2,7 +2,8 @@ use v_htmlescape::escape;
 
 use crate::{
     codegen::{Context, HtmlNode},
-    core::ast::{DecoratorChainNode, Raw},
+    core::ast::{DecoratorChainNode, InlineObjectNode, Raw, TextNode},
+    syntax::{Token, TokenKind},
 };
 
 use super::Walker;
@@ -42,12 +43,45 @@ impl Walker<DecoratorChainNode> for Context<'_> {
                                 .flat_map(|node| node.raw()),
                         )
                         .map(|t| t.text.clone())
-                        .collect::<String>(),
+                        .collect::<String>()
+                        .trim_end(),
                 )
                 .to_string(),
             )]
         } else {
-            self.walk(node.main_text)
+            let node = match *node.main_text {
+                InlineObjectNode::Text(text) => {
+                    let mut tokens = text.tokens;
+                    while let Some((
+                        (
+                            Token {
+                                kind: TokenKind::HorizontalSpace,
+                                ..
+                            },
+                            _,
+                        ),
+                        elements,
+                    )) = tokens.split_last_mut()
+                    {
+                        if let Some((
+                            Token {
+                                kind: TokenKind::PunctuationReverseSolidus,
+                                ..
+                            },
+                            _,
+                        )) = elements.last()
+                        {
+                            break;
+                        }
+
+                        tokens = elements.to_vec();
+                    }
+                    InlineObjectNode::Text(TextNode { tokens })
+                }
+                a @ _ => a,
+            };
+
+            self.walk(node)
         };
         let mut is_first = true;
         for decorator in node.decorators.into_iter().skip(should_be_raw_until) {
