@@ -1,3 +1,5 @@
+use serde_hzdata::HzdataValue;
+
 use crate::{
     api::BlockConstructorRule,
     codegen::{Context, HtmlNode, Walker},
@@ -24,7 +26,7 @@ impl BlockConstructorRule for HxBlockConstructorRule {
         &self,
         context: &mut Context,
         main_text: Vec<InlineObjectNode>,
-        _param: Option<String>,
+        _param: Option<HzdataValue>,
         _: Vec<Vec<InlineObjectNode>>,
     ) -> HtmlNode {
         let main_text = context.walk(main_text);
@@ -33,7 +35,7 @@ impl BlockConstructorRule for HxBlockConstructorRule {
         meta.values.push(Heading {
             name: main_text
                 .iter()
-                .map(|node| node.clone().into_plain_text(&context))
+                .map(|node| node.clone().into_ref(context))
                 .collect(),
             depth: self.depth,
         });
